﻿using System;
using System.Drawing;
using System.Windows.Forms;
using DxAtlas;


namespace ConvertedVbTest
{
  public partial class TestForm : Form
  {

    #region private fields

    /// <summary>
    /// Declare the Atlas object field
    /// </summary>
    private Atlas _atlas;

    /// <summary>
    /// Declare the CustomLayer objects
    /// </summary>
    private CustomLayer _redLabels, _greenLabels, _blueLines, _aquaPoints,
      _niceGlyphs;

    /// <summary>
    /// Set glif and qso default visible state
    /// </summary>
    private bool _glifsVisible = false;
    private bool _qsosVisible = false;

    /// <summary>
    /// Declare the array of Dx objects.
    /// 
    /// Note: in VB 5.0 and 6.0 the Dx array is declared as a Variant array.
    ///   The object is the equivalent in C#, so, all Variant declarations
    ///   must be converted to object. Compare this sample to the VB
    ///   example to understand where Variant must be replaced by object. 
    /// </summary>
    private object[,] Dx = new object[4, 3];

    #endregion private fields

    #region constructors

    public TestForm()
    {
      InitializeComponent(); // C# Initializes and draws the form here
    }

    #endregion constructors

    #region Events

    private void TestForm_Load(object sender, EventArgs e)
    {
      try
      {

        _fillDxLocations();

      }
      catch (Exception ex)
      {
        // I have added try/catch code in each method to aid debugging.
        // you should add your code to handle errors in place of or before
        // the throw statement.
        // your code for the catch here
        throw ex; // or here
      }
    }

    private void _fillDxLocations()
    {
      // define dx locations
      // the f flags indicate the value as a float (single) for the 
      // C# compiler

      Dx[0, 0] = -150f; // longitude
      Dx[0, 1] = 60f;   // latitude
      Dx[0, 2] = " KL7ABC "; // call

      Dx[1, 0] = 18f;
      Dx[1, 1] = 79f;
      Dx[1, 2] = " JW0ZZ ";

      Dx[2, 0] = 46f;
      Dx[2, 1] = -20f;
      Dx[2, 2] = " 5R8QW ";

      Dx[3, 0] = -78f;
      Dx[3, 1] = 25f;
      Dx[3, 2] = " C61UU ";
    }

    private void buttonShowQso_Click(object sender, EventArgs e)
    {
      try
      {

        _showQso();

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }


    private void buttonShowGlyphs_Click(object sender, EventArgs e)
    {
      try
      {
        // this code is the same as the VB code in the sample although the 
        // sample, but has been changed to C# syntax and switching code 
        // has been added.
        _atlas.Map.BeginUpdate();
        _showGlyphs();
        _redLabels.Visible = !_redLabels.Visible;
        _greenLabels.Visible = !_greenLabels.Visible;
        _blueLines.Visible = !_blueLines.Visible;
        _aquaPoints.Visible = !_aquaPoints.Visible;
        _niceGlyphs.Visible = !_niceGlyphs.Visible;
        _atlas.Map.EndUpdate();
        _atlas.Visible = true;
        _atlas.BringToFront();

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void buttonExit_Click(object sender, EventArgs e)
    {
      try
      {
        if (_atlas != null)
        {
          _atlas.Map.CustomLayers.Clear();
        }
        this.Close();
        Application.Exit();

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void buttonConnect_Click(object sender, EventArgs e)
    {
      if (buttonConnect.Text == "Connect")
      {
        // connect to Atlas and configure it
        _connectAndConfigureAtlas();
        buttonConnect.Text = "Disconnect";
        buttonShowQso.Enabled = true;
        buttonShowGlyphs.Enabled = true;
      }
      else if (buttonConnect.Text == "Disconnect")
      {
        buttonConnect.Text = "Connect";
        buttonShowQso.Enabled = false;
        buttonShowGlyphs.Enabled = false;
      }

    }

    #endregion Events

    #region private methods

    private void _showQso()
    {
      // this code is the same as the VB code in the sample although the 
      // sample, but has been changed to C# syntax and switching code added

      _atlas.Map.BeginUpdate();
      _showLines();
      _showPoints();
      _showLabels();

      _redLabels.Visible = !_redLabels.Visible;
      _greenLabels.Visible = !_greenLabels.Visible;
      _blueLines.Visible = !_blueLines.Visible;
      _aquaPoints.Visible = !_aquaPoints.Visible;
      _niceGlyphs.Visible = false;

      _atlas.Map.EndUpdate();
      _atlas.Visible = true;
      _atlas.BringToFront();
    }

    private void _connectAndConfigureAtlas()
    {
      // this code is the same as the VB code in the sample although the 
      // sample, but has been changed to C# syntax
      try
      {

        _atlas = new Atlas();


        _atlas.Map.PrefixesVisible = false;
        _atlas.Map.Projection = EnumProjection.PRJ_AZIMUTHAL;

        // Your Home location goes here 'f' indicates to the compiler
        // that the numeric values are type float (single)
        _atlas.Map.HomeLatitude = 32.67302f;
        _atlas.Map.HomeLongitude = -97.18170f;


        // layers
        _aquaPoints = _atlas.Map.CustomLayers.Add(EnumLayerKind.LK_POINTS);
        _blueLines = _atlas.Map.CustomLayers.Add(EnumLayerKind.LK_LINES);
        _redLabels = _atlas.Map.CustomLayers.Add(EnumLayerKind.LK_LABELS);
        _greenLabels = _atlas.Map.CustomLayers.Add(EnumLayerKind.LK_LABELS);
        _niceGlyphs = _atlas.Map.CustomLayers.Add(EnumLayerKind.LK_GLYPHS);

        // in the beginning these are false due to added switching code
        _redLabels.Visible = false;
        _greenLabels.Visible = false;
        _blueLines.Visible = false;
        _aquaPoints.Visible = false;
        _niceGlyphs.Visible = false;

        // points
        _aquaPoints.BrushColor = EnumColor.clAqua;
        _aquaPoints.PenColor = EnumColor.clBlue;
        _aquaPoints.PointSize = 3;

        // lines
        _blueLines.PenColor = EnumColor.clBlue;

        // red labels
        _redLabels.LabelsTransparent = true;
        _redLabels.PenColor = EnumColor.clRed;
        Font _rlFont = new Font(FontFamily.GenericMonospace,
                9.0F, FontStyle.Bold);


        // green labels
        _greenLabels.LabelsTransparent = false;
        _greenLabels.BrushColor = EnumColor.clLime;
        _greenLabels.PenColor = EnumColor.clGreen;
        Font _glfont = new Font(FontFamily.GenericMonospace,
                9.0F, FontStyle.Bold | FontStyle.Italic);

        // glyphs

        _niceGlyphs.LoadGlyphsFromFile(
          Application.StartupPath + "\\Glyphs.bmp", 1, 15);

        _atlas.Height = 600;
        _atlas.Width = 514;
        this.Top = _atlas.Top + _atlas.Height + 10;
        this.Left = _atlas.Left + ((_atlas.Width - this.Width) / 2);

        //show atlas window
        _atlas.Visible = true;
        buttonShowQso.Enabled = true;
        buttonShowGlyphs.Enabled = true;

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void _showPoints()
    {
      try
      {
        // Note the object declarations....
        object[] points = new object[4];
        for (int i = 0; i < 4; i++)
        {

          object[] pt = new object[2];
          pt[0] = Dx[i, 0];
          pt[1] = Dx[i, 1];
          points[i] = pt;
        }
        _aquaPoints.SetData(points);

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void _showLines()
    {
      try
      {
        // Note the object declarations....
        object[] lines = new object[4];
        for (int i = 0; i < 4; i++)
        {
          //first point
          object[] pt = new object[2];
          object[] ln = new object[2];
          pt[0] = _atlas.Map.HomeLongitude;
          pt[1] = _atlas.Map.HomeLatitude;
          ln[0] = pt;

          // second point
          pt = new object[2];
          pt[0] = Dx[i, 0];
          pt[1] = Dx[i, 1];
          ln[1] = pt;
          lines[i] = ln;
        }
        _blueLines.SetData(lines);

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void _showLabels()
    {
      try
      {
        // Note the object declarations....
        object[] labels = new object[2];
        Font font = new Font(FontFamily.GenericMonospace,
                9.0F, FontStyle.Regular);

        // red Labels
        object[] lb = new object[3];
        lb[0] = Dx[0, 0];
        lb[1] = Dx[0, 1];
        lb[2] = Dx[0, 2];
        labels[0] = lb;

        lb = new object[3];
        lb[0] = Dx[1, 0];
        lb[1] = Dx[1, 1];
        lb[2] = Dx[1, 2];
        labels[1] = lb;

        _redLabels.SetData(labels);

        lb = new object[3];
        // green labels
        lb[0] = Dx[2, 0];
        lb[1] = Dx[2, 1];
        lb[2] = Dx[2, 2];
        labels[0] = lb;

        lb = new object[3];
        lb[0] = Dx[3, 0];
        lb[1] = Dx[3, 1];
        lb[2] = Dx[3, 2];
        labels[1] = lb;

        _greenLabels.SetData(labels);

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    private void _showGlyphs()
    {
      try
      {
        // This had to be modified considerably.
        // The rnd method of apparently VB returns values < 1. C# has several
        // versions of random.  The version that returns nonInteger values is
        // named NextDouble().  Here we are generating a Type double random 
        // value and casting it to float.  Then we cast the float to object.

        object[] glfs = new object[333];
        Random rand = new Random();
        for (int i = 0; i < 333; i++)
        {
          object[] glf = new object[3];

          // cant cast this expression to object so we cast to float
          float n = (float)rand.NextDouble() * 360 - 180;
          // now we have our object
          glf[0] = (object)n;

          n = (float)rand.NextDouble() * 180 - 90;
          glf[1] = (object)n;

          // here we remove the decimal portion of the random number, then
          // convert it to an int32, which we then cast to an object... ;o)
          glf[2] =
            (object)Convert.ToInt32(Math.Truncate(rand.NextDouble() * 16));
          glfs[i] = (object)glf;
        }
        _niceGlyphs.SetData(glfs);

      }
      catch (Exception ex)
      {
        throw ex;
      }
    }

    #endregion private methods
  }
}
